<?php
/*
 * Need to fetch all selected categories from settings once using wp single event with a max number of articles
 *
 * Make sure the fetch articles doesnt get submitted to newswire again
 *
 */
if (!function_exists('fetch_feed')) {
    require_once ABSPATH . WPINC . '/feed.php';
}

class Newswire_Pressroom_Rss {

    private $max_posts = 0;
    /**
     * cache imported articles so we use it to check dpulicates based on article permalink
     */
    private $_imported = array();
    /**
     *
     */
    private $_save_to_db = true;
    /**
     *
     */
    //private $_rssglobal = 'http://newswire.net/rssfeeds/channel/feed/rss/newsroom';
    private $_rssglobal = 'http://newswire.net/rssfeeds/channel/feed/rss/article/category/3';

    /**
     *
     */
    //private $_http://newswire.net/rssfeeds/channel/feed/rss/article/category/2
    private $_cron_schedules = array('newswire_cron_hourly', 'newswire_cron_twice_daily', 'newswire_cron_once_daily');

    private $_default_cats = array(
        'default_pr_feat_cat' => 'News',
        'default_pr_block1_cat' => 'World',
        'default_pr_block2_cat' => 'US',
        'default_pr_block3_cat' => 'Finance',
        'default_pr_block4_cat' => 'Politics',
        'default_pr_block5_cat' => 'Travel',
        'default_pr_block6_cat' => 'Real Estate',
        'default_pr_block7_cat' => 'eBusiness',
        'default_pr_block8_cat' => 'interview',
    );
    /**
     * Class constructor
     */
    public function __construct() {

        $this->_options = newswire_options();

        //add custom cron schedules
        add_filter('cron_schedules', array($this, '_tasks'));
        //cron
        add_action('plugins_loaded', array($this, '_setup_cron'));

        add_action('newswire_pressroom_import_feeds', array($this, 'import_default_theme_blocks'));
        add_action('newswire_pressroom_import_feeds', array($this, '_pressroom_import_user_feeds'));
        add_action('newswire_newsroom_import_feeds', array($this, '_newsroom_import_user_feeds'));
        add_action('newswire_category_import', array($this, '_import_newswire_newsroom_category_default')); //for testing
        add_action('newswire_pressroom_import_feeds', array($this, 'import_news_after_activation'));

        //add_action('newswire_pressroom_import_feeds', array($this, 'regenerate_pr_thumbails'));

        //Debug
        // add_action('admin_footer', array($this, '_pressroom_import_user_feeds'));
        // add_action('admin_footer', array($this, '_newsroom_import_user_feeds'));

        //add_action('newswire_global_import_feeds', array($this, '_import_newswire_newsroom'));
        //newsroom_automated_feed

        //import news right awaya after activation
        //add_action('admin_init', array($this, 'import_news_after_activation'));

        //add_action('prninja_after_activate', array($this, 'import_default_theme_blocks'));

        //add_action('prninja_after_activate', array($this, 'import_news_after_activation'));
        //add_action('generate_default_content', 'import_default_theme_blocks');
        add_action('newswirexpress_after_activate', array($this, 'import_default_theme_blocks'));
        //add_action('admin_footer', array($this, 'freesite_sync'));

       // add_action('cron_freesite_sync_single', array($this, 'freesite_sync_single'), 10, 1);
    }

    public function import_default_theme_blocks() {

        newswire_fetch_categories();
        
        $options = newswire_options();

        $flat = array_map('strtolower', get_option('newswire_categories_flat'));

        if ( !defined('NEWSNINJA')) return;
        
        //var_dump(array_values($this->_default_cats));
        $total = 1;
        for ($x = 0; $x < 1; $x++):
            foreach (array_values($this->_default_cats) as $slug) {
                $id = array_search(strtolower($slug), $flat);

                if ($id) {
                    $url = 'http://www.newswire.net/rssfeeds/channel/feed/rss/article/category/' . $id;
                    //echo $url;
                    //echo '<br>';
                    if (intval($id) == 3) {
                        $total = 3;
                    }

                    $tags = array('newsroom', strtolower($slug));
                    $this->_process_feed($url, array('category_id' => $id, 'import_status' => $options['rss_importstatus'], 'post_tag' => array_map('strtolower', $tags), 'maximum_import' => $total));
                    $total = 1;
                    //break;
                } else {
                    //echo '<pre>';
                    // var_dump($flat);
                    //echo '</pre>';
                }

            } //endforeach
        endfor;
        //exit;
        flush_rewrite_rules();
    }

    /**
     * Add scheduled tasks
     */
    public function _setup_cron() {

        $options = $this->_options;

        //setup cron for global rss import
        //$this->_init_global_rss_cron();

        $this->_initPressRoomRss();
        $this->_initNewsRoomRss();

        //init category rss for newsroom
        $this->_initNewsroomCategories();
    }

    /**
     * custom cron hook callback
     */
    private function _initNewsroomCategories() {

        // if enable continue
        $hook = 'newswire_category_import';

        if (!wp_next_scheduled($hook)) {
            // wp_schedule_event( $timestamp, $recurrence, $hook, $args );
            wp_schedule_event(time() + 3600, 'hourly', $hook);
        }
    }

    private function _initPressRoomRss() {

        $options = $this->_options;

        //user rss cron enable?
        if (empty($options['pressroom_rss_frequency']) || !in_array($options['pressroom_rss_frequency'], $this->_cron_schedules)) {
            return;
        }
        //skip

        // if enable continue
        $hook = 'newswire_pressroom_import_feeds';

        if (!wp_next_scheduled($hook)) {
            // wp_schedule_event( $timestamp, $recurrence, $hook, $args );
            wp_schedule_event(time() + 4600, $options['pressroom_rss_frequency'], $hook);
            //wp_schedule_event( time(), 'hourly', $hook );
        }

    }

    private function _initNewsRoomRss() {

        $options = $this->_options;

        //user rss cron enable?
        if (empty($options['newsroom_rss_frequency']) || !in_array($options['newsroom_rss_frequency'], $this->_cron_schedules)) {
            return;
        }
        //skip

        // if enable continue
        $hook = 'newswire_newsroom_import_feeds';

        if (!wp_next_scheduled($hook)) {
            // wp_schedule_event( $timestamp, $recurrence, $hook, $args );
            wp_schedule_event(time() + 5600, $options['newsroom_rss_frequency'], $hook);
            // wp_schedule_event( time(), 'hourly', $hook );
        }

    }

    /**
     * Run this by default
     * not being used anymore?
     */
    private function _init_global_rss_cron() {

        $hook = 'newswire_global_import_feeds';

        if (!wp_next_scheduled($hook)) {
            // wp_schedule_event( $timestamp, $recurrence, $hook, $args );
            wp_schedule_event(time() + 6600, 'newswire_cron_twice_daily', $hook);
        }
    }

    public function _tasks($schedules) {

        $schedules['newswire_cron_hourly'] = array('interval' => HOUR_IN_SECONDS, 'display' => __('Once Every Hour', 'newswire'));
        $schedules['newswire_cron_once_daily'] = array('interval' => DAY_IN_SECONDS, 'display' => __('Once a Day', 'newswire'));
        $schedules['newswire_cron_twice_daily'] = array('interval' => 12 * HOUR_IN_SECONDS, 'display' => __('Twice A Day', 'newswire'));

        return $schedules;
    }

    public function import_news_after_activation() {
        
        $url = $this->_rssglobal;
        
        $options = newswire_options();

        $this->_process_feed($url, array('category_id' => 3, 'import_status' => $options['rss_importstatus'], 'post_tag' => array('newsroom', 'news'), 'maximum_import' => 10));

    }
    /**
     * global
     */
    public function _import_newswire_newsroom_category_default() {

        //$url = $this->_rssglobal;
        $options = newswire_options();

        $flat = get_option('newswire_categories_flat');

        //newswire_fetch_categories(1);

        if (!empty($options['include_categories']) && is_array($options['include_categories'])) {
            foreach ($options['include_categories'] as $id) {

                list($parent_id, $cat_id) = explode('_', $id);

                if ($parent_id && $cat_id && !isset($flat[$id])) {
                    $parent = $flat[$parent_id];
                    $cat = $flat[$cat_id];
                    $id = $cat_id;

                    $tags = array_map('strtolower', array('newsroom', $parent, $cat));

                } else {
                    $parent = $flat[$id];
                    $tags = array_map('strtolower', array('newsroom', $parent));

                }

                $url = 'http://newswire.net/rssfeeds/channel/feed/rss/article/category/' . $id;
                // echo $url;
                //echo '<br>';

                $this->_process_feed($url, array('category_id' => $id, 'import_status' => $options['rss_importstatus'], 'post_tag' => array_map('strtolower', $tags), 'maximum_import' => $options['categories_maximum_import']));
            }
        }

    }

    // import feeds user defined rss from pressroom
    public function _pressroom_import_user_feeds() {

        $options = $this->_options;

        $urls = trim($options['pressroom_rss']);

        if ($urls == '') {
            return;
        }

        $array_urls = (array) explode("\n", $urls);

        foreach ($array_urls as $url) {

            $url = trim($url);
            //echo $url;
            //update_option('test_rss_feed_'. microtime(true), $url );
            $tags = array('pressroom');
            $this->_process_feed($url, array('forcedate'=> false, 'import_status' => $options['rss_importstatus'], 'post_tag' => $tags, 'maximum_import' => $options['pressroom_rss_maxpost']));

        } //endforeach

    }

    // import feeds user defined rss from newsroom
    public function _newsroom_import_user_feeds() {

        $options = $this->_options;

        $urls = trim($options['newsroom_rss']);

        if ($urls == '') {
            return;
        }

        $array_urls = (array) explode("\n", $urls);

        foreach ($array_urls as $url) {

            $url = trim($url);

            //update_option('test_rss_feed_'. microtime(true), $url );
            //set parent and sub category as tag
            $tags = array('newsroom');
            $this->_process_feed($url, array('import_status' => $options['rss_importstatus'], 'post_tag' => $tags, 'maximum_import' => $options['newsroom_rss_maxpost']));

        } //endforeach

    }

    public function fetch_single_article($article_id) {

        $url = sprintf('http://www.newswire.net/api/v1/article/%s', $article_id);

        $response = wp_remote_get($url);

        if (is_wp_error($response)) {
            return;
        }

        $article = json_decode(wp_remote_retrieve_body($response), true);

        if ($article && is_array($article)) {
            $ID = wp_insert_post(array(
                'post_title' => $article['title'],
                'post_content' => $article['body'],
                'post_excerpt' => $article['description'],
                'post_status' => 'publish',
                'post_type' => 'pr',
                'tags_input' => array('newsroom'),

            ));
            //update post meta
            update_post_meta($ID, 'newswire_data', $article);
        }
    }

    /**
     * Process rss per url
     *
     * @param $url string
     * @param $params mixed
     *
     * @return void
     */
    public function _process_feed($url, $params = null) {

        //our own way of tagging cron is running
        newswire_var('cron', 1);

        //merge pass params and newswire_options
        $options = wp_parse_args($this->_options, $params);

        //skip if cat max settings is set 0
        if ( empty($params['maximum_import']) ) {
            newswire_var('cron', null);
            return;
        }

        $max_posts = $params['maximum_import'] ? $params['maximum_import'] : 10;
        

        //var_dump($max_posts);
        //forcedate by default
        if ( !isset($params['forcedate']) ) {
            $params['forcedate'] = true;
        }
        //http get using  simple pie
        $rss = fetch_feed($url);

        // Checks that the object is created correctly
        if (!is_wp_error($rss)):

            // Figure out how many total items there are, but limit it to 5.
            $maxitems = $rss->get_item_quantity(50);

            // Build an array of all the items, starting with element 0 (first element).
            $rss_items = $rss->get_items(0, $maxitems);

            if ($this->_save_to_db) {

                // $saved_posts = array();

                foreach ($rss_items as $item) {
                    
                    //var_export( $item->get_author());

                    if (!$max_posts) {
                        break;
                    }

                    if ($this->max_posts >= 50/* total max so not to stress server*/) {
                        break;
                    }
                    //skip article older than one month
                    //$item->get_date('Y-m-d H:i:s')
                    if ( $params['forcedate']  && strtotime($item->get_date('Y-m-d H:i:s')) < strtotime('-60 days')){
                        continue;
                    }

                    $link = esc_url($item->get_permalink());

                    if (!in_array($link, $this->_imported)) {

                        


                        if (!$found_id = $this->_post_exists($link)) {

                            $this->_imported[] = $link;

                            $image = $item->get_enclosures();

                            $new_post = array(
                                'post_title' => $item->get_title(),
                                'post_excerpt' => $item->get_description(),
                                'post_content' => $this->_parse_content($item),
                                'post_type' => 'pr',
                                'post_status' => $options['import_status'],
                                //'post_author'   => $options['settings']['author_id'], default to admin
                                //'post_category' => array($category_id),
                                //'comment_status'=> $options['settings']['allow_comments'],
                                'tags_input' => $params['post_tag'],
                                'post_date' => $item->get_date('Y-m-d H:i:s'),
                            );

                            $post_id = wp_insert_post($new_post);

                            if ($post_id) {
                                //var_dump($max_posts);

                                $this->max_posts += 1;
                                $max_posts--;

                                //wp_set_post_tags($post_id, $options['post_tag']);
                                //tag press release so we the plugin dont need to resubmit it from when user edit
                                update_post_meta($post_id, 'rss_source_url', $link);
                                preg_match('/\((.*?)\)/', $item->get_author()->email, $author);
                                update_post_meta($post_id, 'author', $author[1]);

                                //
                                if ($options['category_id']) {
                                    update_post_meta($post_id, 'newswire_category', $options['category_id']);
                                }

                                //array_push($saved_posts, $new_post);

                                //$mydata = array('img_url' => $image[0]->link);
                                //update_post_meta($post_id, NEWSWIRE_POST_META_CUSTOM_FIELDS, $mydata);

                                //fetch article details to fill other meta data from newswire
                                //works only to newswire feed
                                $this->maybe_update_article_details($post_id, $link, $image[0]->link);
                                $this->set_post_thumbnail($post_id, $image[0]->link);

                            }

                        } //endif
                    else {
                        wp_set_post_tags($found_id, $options['post_tag']);
                        // var_dump('duplicate');
                        // var_dump($link);
                    }
                }

            } //endforeach

        } //endif
        endif;

        //endif
        //exit;
        /*
        echo '<pre>';
        var_dump($this->_imported);
        echo '</pre>';*/
        newswire_var('cron', null);
        //exit;
    }

    /**
     *
     * @param $item object rss item
     * @param $feed_title
     *
     * @return $c string rss item content
     */
    function _parse_content($item, $feed_title = '') {

        $c = $item->get_content() != "" ? $item->get_content() : $item->get_description();
        return $c;
        /*
    $parsed_content = str_replace('{$content}', $c, $post_template);
    $parsed_content = str_replace('{$permalink}', esc_url( $item->get_permalink() ), $parsed_content);
    $parsed_content = str_replace('{$feed_title}', $feed_title, $parsed_content);
    $parsed_content = str_replace('{$title}', $item->get_title(), $parsed_content);

    if($strip_html == 'true')
    {
    $parsed_content = strip_tags($parsed_content);
    }
    return $parsed_content;
     */
    }

    /**
     * Verify if rss item has been imported to db
     *
     * @param $permalink string valid url
     *
     * @return boolean true | false
     */
    public function _post_exists($permalink) {
        return newswire_post_exists($permalink);
    }

    /**
     * Currenlty only works for newswire rss
     *
     * @param $post_id integer pr object id
     * @param $url rss item link
     *
     * @return void
     */
    public function maybe_update_article_details($post_id, $url, $img) {
        //parse url

        if (strpos($url, 'newswire.net') > 0) {

            preg_match_all('|newsroom/(.*?)/([0-9]*)[-]|is', $url, $matches);
            $id = intval($matches[2][0]);

            //parse
            $api = 'http://newswire.net/api/v1/article/' . $id;
            $response = wp_remote_get($api);
            $article = json_decode(wp_remote_retrieve_body($response), true);
            wp_update_post(array("ID" => $post_id, 'post_content' => $article['body']));
            update_post_meta($post_id, NEWSWIRE_ARTICLE_ID, $id);

            unset($article['body']);
            $article['img_url'] = $img;
            update_post_meta($post_id, 'newswire_data', $article);

            //$response = wp_remote_get($url);
            //$body = wp_remote_retrieve_body( $response );
            //parse content
            //preg_match_all('|<div id="article_body_main" itemprop="articleBody">(.*?)</div>|siU', $body, $matches );
            //wp_update_post( array("ID"=>$post_id, 'post_content'=> $matches[1][0]) );
        }
    }

    public function regenerate_pr_thumbails() {

        $args = array('post_type' => 'pr', 'post_status' => 'publish', 'posts_per_page' => -1);
        $posts = get_posts($args);
        foreach ($posts as $post) {

            if (!has_post_thumbnail($post->ID)) {
                prninja_set_pr_post_thumbnail($post->id);
            }

        }
    }
    /**
     *
     * Set post thumbnail for any image grab from the given rss import
     * @todo: make this work to support existing site listing the newsroom nad pressroom content as blog
     *
     */
    public function set_post_thumbnail($post_id, $image_url) {
        if (defined('DOING_CRON') && DOING_CRON) {
            if (function_exists('prninja_set_pr_post_thumbnail')) {
                prninja_set_pr_post_thumbnail($post_id);
            }
        }

        //return;
        /*
    $upload_dir = wp_upload_dir();
    $image_data = @file_get_contents( trim($image_url) );
    $filename = basename($image_url);
    if(wp_mkdir_p($upload_dir['path']))
    $file = $upload_dir['path'] . '/' . $filename;
    else
    $file = $upload_dir['basedir'] . '/' . $filename;
    file_put_contents($file, $image_data);

    $wp_filetype = wp_check_filetype($filename, null );
    $attachment = array(
    'post_mime_type' => $wp_filetype['type'],
    'post_title' => sanitize_file_name($filename),
    'post_content' => '',
    'post_status' => 'inherit'
    );
    $attach_id = wp_insert_attachment( $attachment, $file, $post_id );
    require_once(ABSPATH . 'wp-admin/includes/image.php');
    $attach_data = wp_generate_attachment_metadata( $attach_id, $file );
    wp_update_attachment_metadata( $attach_id, $attach_data );

    set_post_thumbnail( $post_id, $attach_id );
    unset($image_data);
     */

    }


    /**
    * run everyminutes? by 5 article
    */
    public function freesite_sync() {



        $action = $_POST['action'];
        $article = $_POST['article'];
        $meta = $_POST['meta'];
        $author = $_POST['author'];
        $api_key  = $_POST['api_key'];
        $email = $_POST['email'];
        $category = $_POST['category']; 
    }

    /**
    * running
    */
    public function freesite_sync_single($post_id) {
        
        $options = newswire_options();
        
        //if ( $options['api_validated']) {
        
        //  return;
    //  }

        $action = 'newswire_freesites_sync';

        //article
        $article = get_post($post_id);
        
        //$tags = wp_get_post_tags( $post_id) ;
        error_reporting(0);
        ignore_user_abort();
        set_time_limit(0);
        
        $args = array();

        $args['timeout'] = 7;
        //get tags
        $tags = array();
        $terms = wp_get_post_tags($post_id);
        foreach($terms as $term) {
            $tags[] = $term->name;
        }
        //merge with options
        $post_meta = newswire_data($post_id);
            
        //CONSERVATIVETHOUGHTS.US, MORNINGSTARTRIBUNE.COM, ONLINEHERALDNEWS.COM, PRESSCHICAGO.COM, THECITYNEWS.ORG
        $fressites = array( 
                'http://thecitynews.org/',
                'http://presschicago.com/',
                'http://onlineheraldnews.com/', 
                'http://morningstartribune.com/',
                'http://conservativethoughts.us/'
                
                //'http://local.wpver.dev/ver4.1.1/'
            );

        foreach($fressites as $url) {
            
            $url .= '?action=newswire_freesites_sync';
            //send post meta
            $args['body']['meta'] = $post_meta;
            $args['body']['postback_url'] = get_permalink( $post_id );

            //send article
            $args['body']['article'] = array(
                'post_title' => $article->post_title,
                'post_content' => $article->post_content,
                'post_excerpt' => $article->post_excerpt,
                'post_type' => 'pr',
                'post_status' => 'publish',
                'tags_input' => $tags,
            );

            //set api config
            $args['body']['api_key'] = $options['newswire_api_key'];
            $args['body']['email'] = $options['newswire_api_email'];

            $response = wp_remote_post( $url, $args );
            //check
            //update_post_meta($post_id, time(), $url );
            if ( !is_wp_error($response) )
                update_post_meta($post_id, 'freesites_submission', 2, 1 );

        }
    }
} //end class

$newswire_rss = new Newswire_Pressroom_Rss;


