<?php
/**
* Widgets are classses extended from WP_Widget
*
*/
if ( !defined( 'ABSPATH' ) ) exit;


/**
* Category Widgets - newswire categories
*/
class Newswire_Category_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'newswire-widget-categories', // Base ID
            __('Newswire Categories', 'newswire'), // Name
            array( 'description' => __( 'Display Newsroom Categories', 'newsroom' ), ) // Args
        );
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );

        //show only top categories for now
        $categories = newswire_fetch_categories();
        foreach($categories as $id=>$top) {
           // var_dump($top);
            /*
            if ( is_array($top['sub'])) {
                $subcats_html = '';
                foreach($top['sub'] as $subcat_id => $subcat)
                    $subcats_html .= sprintf('<li class=""><a href="^%s">%s</a></li>', $subcat['permalink'], $subcat['name']);

                $items.= sprintf('<li class=""><a href="^%s">%s</a> <ul>%s</ul></li>', $top['permalink'], $top['name'], $subcats_html);
            } else */
                $items.= sprintf('<li class=""><a href="%s">%s</a></li>', $top['permalink'], $top['name']);

        }
        $html .= sprintf('<ul class="">%s</ul>', $items);

        echo $args['before_widget'];
        if ( ! empty( $title ) )
            echo $args['before_title'] . $title . $args['after_title'];
        //echo __( 'Hello, World! Categories goes here', 'text_domain' );
        echo $html;
        echo $args['after_widget'];
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        if ( isset( $instance[ 'title' ] ) ) {
            $title = $instance[ 'title' ];
        }
        else {
            $title = __( 'New title', 'newswire' );
        }
        ?>
        <p>
        <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
        <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
        <label for="<?php echo $this->get_field_id( 'excat' ); ?>"><?php _e( 'Exclude Categories:' ); ?></label> 
        <input class="widefat" id="<?php echo $this->get_field_id( 'excat' ); ?>" name="<?php echo $this->get_field_name( 'excat' ); ?>" type="text" value="<?php echo esc_attr( $excat ); ?>">
        </p>
        <?php 
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['excat'] = ( ! empty( $new_instance['excat'] ) ) ? strip_tags( $new_instance['excat'] ) : '';

        return $instance;
    }
}//end class
 

/** 
* latest articles 
* 
*/
class Newswire_Latest_Article_Widget extends WP_Widget {
    
    /**
    *
    */
    public function __construct() {
        parent::__construct($base_id ='newswire-widget-toparticles', 
            $name = __('Newswire Articles', 'newswire'), 
            $args = array('description'=> __('Show Latest articles from newswire', 'newswire'))
        );
    }
    
    /**
    *<li>
<a href="{permalink}" title="{description}">
    <img src="{photo_url} " style="float:left; width:35%;">
</a>
<h4 style="color:black; float:right; clear:none; width:63%;">
    <a href="{permalink}" title="{description}" style="color: black; float: left;">{title}</a>
</h4>
<a href="{permalink}" title="{description}">
    <p style="clear:both;">{description}</p>
</a>
</li>

    */
    public function widget($args, $instance) {

        $title = apply_filters( 'widget_title', $instance['title'] );

        //$result = json_decode(newswire_remote_article(), true);

        //$articles = $result['articles'];

 //total default
        if ( isset( $instance[ 'totalarticles' ] ) ) {
            $totalarticles = $instance[ 'totalarticles' ];
        }
        else {
            $totalarticles = 10;
        }
        

        $url = 'http://newswire.net/rssfeeds/channel/feed/rss/newsroom';
        $rss = fetch_feed($url);

        // Checks that the object is created correctly
        if (!is_wp_error($rss)):

            // Figure out how many total items there are, but limit it to 5.
            $maxitems  = $rss->get_item_quantity($totalarticles);
        
            // Figure out how many total items there are, but limit it to 5.
            
            // Build an array of all the items, starting with element 0 (first element).
            $articles = $rss->get_items(0, $maxitems);

        endif;
      
        if ( false === $articles) return;

        //show latest articles
        $template = $instance['template'];
        foreach($articles  as $article) {
            $ctr++;
            $html = $template;
            //$items .= newswire_article_template($article, $template);
            $image = $article->get_enclosures();
            
            $html = str_replace('{permalink}', $article->get_permalink(), $html);
            $html = str_replace('{description}', $article->get_description(), $html);
            $html = str_replace('{photo_url}', $image[0]->link, $html);
            $html = str_replace('{title}', $article->get_title(), $html);
            $html = str_replace('{dateline}', $article->get_date(), $html);
            //$html = str_replace('{permalink}', $article->get_description(), $html);


            $items .= $html;

            if ( $ctr > $totalarticles ) break;
        }

        echo $args['before_widget'];
        
        if ( ! empty( $title ) )
            echo $args['before_title'] . $title . $args['after_title'];

        echo sprintf('<ul>%s</ul>', $items);
        printf('<a href="%s" style="color:blue;">More News</a>', 'http://newswire.net/newsroom');
        echo $args['after_widget'];

    }

    /**
    * 
    */
    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['totalarticles'] = ( ! empty( $new_instance['totalarticles'] ) ) ? strip_tags( $new_instance['totalarticles'] ) : '';
        $instance['template'] = ( ! empty( $new_instance['template'] ) ) ?  $new_instance['template']  : '';

        return $instance;

    }

    /**
    *
    */
    public function form( $instance ) {

        if ( isset( $instance[ 'title' ] ) ) {
            $title = $instance[ 'title' ];
        }
        else {
            $title = __( 'New title', 'newswire' );
        }

        //total default
        if ( isset( $instance[ 'totalarticles' ] ) ) {
            $totalarticles = $instance[ 'totalarticles' ];
        }
        else {
            $totalarticles = 10;
        }

         //template default
        if ( isset( $instance[ 'template' ] ) ) {
            $template = $instance[ 'template' ];
        }
        else {
            $template = '<li>
<a href="{permalink}" title="{description}">
    <img src="{photo_url} " style="float:left; width:35%;">
</a>
<h4 style="color:black; float:right; clear:none; width:63%;">
    <a href="{permalink}" title="{description}" style="color: black; float: left;">{title}</a>
</h4>
<a href="{permalink}" title="{description}">
    <p style="clear:both; margin-bottom: 0">{description}</p>
    <p class="date">{dateline}</p>
</a>
</li>
';
        }
        ?><p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'totalarticles' ); ?>"><?php _e( 'Number of Articles:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'totalarticles' ); ?>" name="<?php echo $this->get_field_name( 'totalarticles' ); ?>" type="text" value="<?php echo esc_attr( $totalarticles ); ?>">
            <span class="description">Max of 20</span>
        </p>
<?php /*
        <p>      
            <?php if ( $instance['featuredonly'] ): ?>
                <input class="widefat" id="<?php echo $this->get_field_id( 'featuredonly' ); ?>" name="<?php echo $this->get_field_name( 'featuredonly' ); ?>" type="checkbox" value="1" checked="checked">
                <label for="<?php echo $this->get_field_id( 'featuredonly' ); ?>"><?php _e( 'Show Featured Articles Only' ); ?></label> 
            <?php else: ?>
                <input class="widefat" id="<?php echo $this->get_field_id( 'featuredonly' ); ?>" name="<?php echo $this->get_field_name( 'featuredonly' ); ?>" type="checkbox" value="1" >
                <label for="<?php echo $this->get_field_id( 'featuredonly' ); ?>"><?php _e( 'Show Featured Articles Only' ); ?></label> 
            <?php endif; ?>
  
    </p> */
  ?>      
       
        <p>
            <label for="<?php echo $this->get_field_id( 'template' ); ?>"><?php _e( 'Article Item Template:' ); ?></label> 
            <textarea rows="6" class="widefat" id="<?php echo $this->get_field_id( 'template' ); ?>" name="<?php echo $this->get_field_name( 'template' ); ?>" ><?php echo esc_attr( $template ); ?></textarea>
            <span class="description">Use the following tokens : {title}, {description}, {photo_url} {permalink}</span>
        </p>
        <?php 
    }
}//end class



//Single Page widget

/** 
*  IFRAMES = embed, mapsembed, fbembed, adsembed, webembed
* 
*/
class NewswireXpress_Single_IFrame_Widget extends WP_Widget {
    
    /**
    *
    */
    public function __construct() {
        parent::__construct($base_id ='press-release-iframes',
            $name = __('Press Release Content - IFrame Builder', 'newswire'), 
            $args = array('description'=> __('Show Embedded Iframes - (Video,Google Maps, Facebook, AdSense, Website)', 'newswire'))
        );
    }
    
    /**
    *
    */
    public function widget($args, $instance) {

        global $post;

        $title = apply_filters( 'widget_title', $instance['title'] );
        $iframe_builder = $instance['iframe_builder'] ;
        


        if ( ! is_single() ) return;

        if (  get_post_type( $post->ID ) == 'pr'  ) {    

            $meta =  newswire_data();

            //no vide embed?
            //if ( $meta['embed'] == '' ) return;

            echo $args['before_widget'];
            
            if ( ! empty( $title ) )
                echo $args['before_title'] . $title . $args['after_title'];

           //print widget
            if ( isset($meta[$iframe_builder] ) && $meta[$iframe_builder] !='' )

                echo $meta[$iframe_builder];
            else {

                if ( $iframe_builder == 'fbembed') {
                    newswire_print_default_fb();
                }
            }
            echo $args['after_widget'];
            wp_reset_postdata();
        }

       
    }

    /**
    * 
    */
    public function update($new_instance, $old_instance) {
        
        $instance = array();
        
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['iframe_builder'] = ( ! empty( $new_instance['iframe_builder'] ) ) ? strip_tags( $new_instance['iframe_builder'] ) : '';
        
        return $instance;

    }

    /**
    *
    */
    public function form( $instance ) {

        if ( isset( $instance[ 'title' ] ) ) {
            $title = $instance[ 'title' ];
        }
        else {
            $title = __( 'New title', 'newswire' );
        }
        
        $iframe_builder = $instance['iframe_builder'];

        $iframes = array('embed'=> 'Video', 'mapsembed'=>'Google Maps', 'fbembed'=> 'Facebook', 'adsembed'=>'AdSense', 'webembed'=> 'Website');
        //get post meta
        //var_dump($iframe_builder);

        ?><div class="prninja-widget-iframe">
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
            <input class="widefat title" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'iframe_builder' ); ?>"><?php _e( 'Show Article Iframe' ); ?></label> 
            <select class="widefat pressroom-widget-select"  id="<?php echo $this->get_field_id( 'iframe_builder' ); ?>" name="<?php echo $this->get_field_name( 'iframe_builder' ); ?>" >
                <option value="">-select-</option>
            <?php 
                foreach($iframes as $iframe=>$text) :
                        if ( $iframe_builder == $iframe ) $selected ="selected"; else $selected = '';
                    printf('<option value="%s" %s>%s</option>', $iframe, $selected, $text);
                endforeach;
            ?>
            </select>
           
            <span class="description"></span>
        </p>
        </div>
<?php /*
        <p>      
            <?php if ( $instance['featuredonly'] ): ?>
                <input class="widefat" id="<?php echo $this->get_field_id( 'featuredonly' ); ?>" name="<?php echo $this->get_field_name( 'featuredonly' ); ?>" type="checkbox" value="1" checked="checked">
                <label for="<?php echo $this->get_field_id( 'featuredonly' ); ?>"><?php _e( 'Show Featured Articles Only' ); ?></label> 
            <?php else: ?>
                <input class="widefat" id="<?php echo $this->get_field_id( 'featuredonly' ); ?>" name="<?php echo $this->get_field_name( 'featuredonly' ); ?>" type="checkbox" value="1" >
                <label for="<?php echo $this->get_field_id( 'featuredonly' ); ?>"><?php _e( 'Show Featured Articles Only' ); ?></label> 
            <?php endif; ?>
  
    */
  ?>     
        <?php 
    }
}//end class





if ( !function_exists('newswireXpress_register_widgets')):
/**
* Register all the widgets now
*/
add_action('widgets_init', 'newswireXpress_register_widgets' );
function newswirexpress_register_widgets() {
    //register_widget('Newswire_Featured_Article_Widget');
    register_widget('Newswire_Latest_Article_Widget');
    register_widget('Newswire_Category_Widget');
    register_widget('NewswireXpress_Single_IFrame_Widget' );
}
endif;

